@@ -10,8 +10,13 @@
 ##' @name abf
 ##' @rdname abf
 ##' @include spatPomp_class.R
+##' @author Kidus Asfaw
 ##' @family particle filter methods
 ##' @importFrom foreach %dopar%
+##' @references
+##'
+##' \ionides2021
+##'
 ##' @param object A \code{spatPomp} object.
 ##' @param \dots If a \code{params} argument is specified, \code{abf} will estimate the likelihood at that parameter set instead of at \code{coef(object)}.
 ##' @param Np The number of particles used within each replicate for the adapted simulations.
@@ -22,8 +27,10 @@
 ##' @param tol If the resampling weight for a particle is zero due to floating-point precision issues, it is set to the value of \code{tol} since resampling has to be done.
 ##' @param verbose logical; if \code{TRUE}, messages updating the user on progress will be printed to the console.
 ##' @examples
+##' # Complete examples are provided in the package tests
+##' \dontrun{
 ##' # Create a simulation of a Brownian motion
-##' b <- bm(U=3, N=10)
+##' b <- bm(U=2, N=5)
 ##'
 ##' # Create a neighborhood function mapping a point in space-time
 ##' # to a list of neighboring points in space-time
@@ -40,6 +47,7 @@
 ##'
 ##' # Get the likelihood estimate from ABF
 ##' logLik(abfd_bm)
+##' }
 ##' @return Upon successful completion, \code{abf()} returns an object of class
 ##' \sQuote{abfd_spatPomp} containing the algorithmic parameters used to run \code{abf()}
 ##' and the estimated likelihood.
@@ -89,7 +97,7 @@ setClass(
 
 abf_internal <- function (object, Np, nbhd, tol, ..., verbose, .gnsi = TRUE) {
   ep <- paste0("in ",sQuote("abf"),": ")
-  p_object <- pomp(object,...,verbose=verbose)
+  p_object <- pomp(object,...,verbose=FALSE)
   object <- new("spatPomp",p_object,
     unit_covarnames = object@unit_covarnames,
     shared_covarnames = object@shared_covarnames,
@@ -104,8 +112,7 @@ abf_internal <- function (object, Np, nbhd, tol, ..., verbose, .gnsi = TRUE) {
     unit_obsnames = object@unit_obsnames,
     unit_accumvars = object@unit_accumvars)
   params <- coef(object)
-  verbose = FALSE
-  pompLoad(object,verbose)
+  pompLoad(object,verbose=FALSE)
   gnsi <- as.logical(.gnsi)
   if (length(params)==0)
     stop(ep,sQuote("params")," must be specified",call.=FALSE)
@@ -197,37 +204,27 @@ abf_internal <- function (object, Np, nbhd, tol, ..., verbose, .gnsi = TRUE) {
           conditionMessage(e),call.=FALSE)
       }
     )
-                                        #weights[weights == 0] <- tol
     log_cond_densities[,,nt] <- log_weights[,,1]
     log_resamp_weights <- apply(log_weights[,,1,drop=FALSE], 2, function(x) sum(x))
     max_log_resamp_weights <- max(log_resamp_weights)
-                                        # if any particle's resampling weight is zero replace by tolerance
     if(all(is.infinite(log_resamp_weights))) log_resamp_weights <- rep(log(tol), Np[1L])
     else log_resamp_weights <- log_resamp_weights - max_log_resamp_weights
     resamp_weights <- exp(log_resamp_weights)
-                                        #if(all(resamp_weights == 0)) resamp_weights <- rep(tol, Np[1L])
     gnsi <- FALSE
 
-    ## do resampling if filtering has not failed
-    xx <- tryCatch(
-      .Call(
+    xx <- .Call(
         abf_computations,
         x=X,
         params=params,
         Np=Np[nt+1],
         trackancestry=FALSE,
         weights=resamp_weights
-      ),
-      error = function (e) {
-        stop(ep,conditionMessage(e),call.=FALSE) # nocov
-      }
     )
 
     x <- xx$states
     params <- xx$params
 
-    if (verbose && (nt%%5==0))
-      cat("abf timestep",nt,"of",ntimes,"finished\n")
+    if (verbose && (nt%%5==0)) cat("abf timestep",nt,"of",ntimes,"finished\n")
   } ## end of main loop
 
                                         # compute locally combined pred. weights for each time, unit and particle
@@ -254,7 +251,7 @@ abf_internal <- function (object, Np, nbhd, tol, ..., verbose, .gnsi = TRUE) {
   }
   log_wm_times_wp_avg <- apply(log_loc_comb_pred_weights + log_cond_densities, c(1,3), FUN = logmeanexp)
   log_wp_avg <- apply(log_loc_comb_pred_weights, c(1,3), FUN = logmeanexp)
-  pompUnload(object,verbose=verbose)
+  pompUnload(object,verbose=FALSE)
   new(
     "adapted_replicate",
     log_wm_times_wp_avg = log_wm_times_wp_avg,
